Actions, Resources, and Condition Keys for Amazon Forecast - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Forecast.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon Forecast

Amazon Forecast (service prefix: `forecast`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

Topics

- Actions Defined by Amazon Forecast
- Resources Defined by Amazon Forecast
- Condition Keys for Amazon Forecast

## Actions Defined by Amazon Forecast

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateDataset | Creates a dataset | Write | dataset* |  |
CreateDatasetGroup | Creates a dataset group | Write | datasetGroup* |  |
CreateDatasetImportJob | Creates a dataset import job | Write | datasetImportJob* |  |
CreateForecast | Creates a forecast | Write | predictor* |  |
CreateForecastExportJob | Creates a forecast export job | Write | forecast* |  |
CreatePredictor | Creates a predictor | Write | datasetGroup* |  |
DeleteDataset | Deletes a dataset | Write | dataset* |  |
DeleteDatasetGroup | Deletes a dataset group | Write | datasetGroup* |  |
DeleteDatasetImportJob | Deletes a dataset import job | Write | datasetImportJob* |  |
DeleteForecast | Deletes a forecast | Write | forecast* |  |
DeleteForecastExportJob | Deletes a forecast export job | Write | forecastExport* |  |
DeletePredictor | Deletes a predictor | Write | predictor* |  |
DescribeDataset | Describes a dataset | Read | dataset* |  |
DescribeDatasetGroup | Describes a dataset group | Read | datasetGroup* |  |
DescribeDatasetImportJob | Describes a dataset import job | Read | datasetImportJob* |  |
DescribeForecast | Describes a forecast | Read | forecast* |  |
DescribeForecastExportJob | Describes a forecast export job | Read | forecastExport* |  |
DescribePredictor | Describes a predictor | Read | predictor* |  |
GetAccuracyMetrics | Gets Accuracy Metrics for a predictor | Read | predictor* |  |
ListDatasetGroups | Lists dataset groups | List |  |  |
ListDatasetImportJobs | Lists dataset import jobs | List |  |  |
ListDatasets | Lists datasets | List |  |  |
ListForecastExportJobs | Lists forecast export jobs | List |  |  |
ListForecasts | Lists forecasts | List |  |  |
ListPredictors | Lists predictors | List |  |  |
QueryForecast | Retrieves a forecast for a single item | Read | forecast* |  |
UpdateDatasetGroup | Updates a dataset group | Write | dataset* |  |
datasetGroup* |  |

## Resources Defined by Amazon Forecast

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
dataset | `arn:${Partition}:forecast:${Region}:${Account}:dataset/${ResourceId}` |
datasetGroup | `arn:${Partition}:forecast:${Region}:${Account}:dataset-group/${ResourceId}` |
datasetImportJob | `arn:${Partition}:forecast:${Region}:${Account}:dataset-import-job/${ResourceId}` |
algorithm | `arn:${Partition}:forecast:::algorithm/${ResourceId}` |
predictor | `arn:${Partition}:forecast:${Region}:${Account}:predictor/${ResourceId}` |
forecast | `arn:${Partition}:forecast:${Region}:${Account}:forecast/${ResourceId}` |
forecastExport | `arn:${Partition}:forecast:${Region}:${Account}:forecast-export-job/${ResourceId}` |

## Condition Keys for Amazon Forecast

Forecast has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon Forecast
- Resources Defined by Amazon Forecast
- Condition Keys for Amazon Forecast

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more